@@ -124,7 +124,7 @@ summaryViewNew builder = do
       [ cellText := show ovf ]
     addSparksColumn "Dud" $ \(_, SparkCounts _ _ _ dud _ _) ->
       [ cellText := show dud ]
-    addSparksColumn "GC'd" $ \(_, SparkCounts _ _ _ _ gc _) ->
+    addSparksColumn "GCed" $ \(_, SparkCounts _ _ _ _ gc _) ->
       [ cellText := show gc ]
     addSparksColumn "Fizzled" $ \(_, SparkCounts _ _ _ _ _ fiz) ->
       [ cellText := show fiz ]
@@ -186,9 +186,9 @@ setSummaryStats view SummaryStats{..} hasHeapEvents = do
 setTimeStats :: SummaryView -> TimeStats -> IO ()
 setTimeStats SummaryView{..} TimeStats{..} =
   mapM_ (\(label, text) -> set label [ labelText := text ])
-    [ (labelTimeTotal       , showFFloat (Just 2) (timeToSecondsDbl timeTotal) "s")
-    , (labelTimeMutator     , showFFloat (Just 2) (timeToSecondsDbl timeMutator) "s")
-    , (labelTimeGC          , showFFloat (Just 2) (timeToSecondsDbl timeGC) "s")
+    [ (labelTimeTotal       , showTimeWithUnit timeTotal)
+    , (labelTimeMutator     , showTimeWithUnit timeMutator)
+    , (labelTimeGC          , showTimeWithUnit timeGC)
     , (labelTimeProductivity, showFFloat (Just 1) (timeProductivity * 100) "% of mutator vs total")
     ]
 
@@ -563,6 +563,17 @@ sparkStats StatsAccum{dsparkTable} =
 
 ------------------------------------------------------------------------------
 
+showTimeWithUnit :: Integral a => a -> String
+showTimeWithUnit t =
+    showFFloat (Just 3) t'' unit
+  where
+    (t'', unit) =
+      case timeToSecondsDbl t of
+        t' | t' < 1e-6  -> (t' / 1e-9, "ns")
+           | t' < 1e-3  -> (t' / 1e-6, "μs")
+           | t' < 1     -> (t' / 1e-3, "ms")
+           | otherwise  -> (t', "s")
+
 timeToSecondsDbl :: Integral a => a -> Double
 timeToSecondsDbl t = timeToSeconds $ fromIntegral t
 
@@ -703,7 +714,7 @@ accumEvent !statsAccum ev =
       -- For events that contain discrete increments. We assume the event
       -- is emitted close to the end of the process it measures,
       -- so we ignore the first found event, because most of the process
-      -- could have happened before the start of the current inverval.
+      -- could have happened before the start of the current interval.
       -- This is consistent with @alterCounter@. For interval beginning
       -- at time 0, we start with @Just 0@.
       alterIncrement _ Nothing = Just 0
@@ -870,7 +881,7 @@ accumEvent !statsAccum ev =
                         }
                   -- Cap is not in the GC. Mark it as idle to complete
                   -- the identification of caps that take part
-                  -- in the current GC. Without overwritin the mode,
+                  -- in the current GC. Without overwriting the mode,
                   -- the cap could be processed later on as if
                   -- it took part in the GC, giving wrong results.
                   ModeEnd  -> dGC { gcMode = ModeIdle }
@@ -923,7 +934,7 @@ accumEvent !statsAccum ev =
                  ModeIdle  -> errorAs "scanEvents: EndGC ModeIdle"
                               $ sd { dGCTable = IM.insert cap endedGC dGCTable }
           SparkCounters crt dud ovf cnv fiz gcd _rem ->
-            -- We are guranteed the first spark counters event has all zeroes,
+            -- We are guaranteed the first spark counters event has all zeroes,
             -- do we don't need to rig the counters for maximal interval.
             let current = RtsSpark crt dud ovf cnv fiz gcd
             in sd { dsparkTable =
