@@ -76,51 +76,51 @@ renderView TimelineState{timelineDrawingArea, timelineVAdj, timelinePrevView}
   win <- widgetGetDrawWindow timelineDrawingArea
   renderWithDrawable win $ do
 
-  let renderToNewSurface = do
-        new_surface <- withTargetSurface $ \surface ->
-          liftIO $ createSimilarSurface surface ContentColor w (height params)
-        renderWith new_surface $ do
-          clearWhite
-          renderTraces params hecs rect
-        return new_surface
+    let renderToNewSurface = do
+          new_surface <- withTargetSurface $ \surface ->
+            liftIO $ createSimilarSurface surface ContentColor w (height params)
+          renderWith new_surface $ do
+            clearWhite
+            renderTraces params hecs rect
+          return new_surface
 
-  surface <-
-    case prev_view of
-      Nothing -> renderToNewSurface
+    surface <-
+      case prev_view of
+        Nothing -> renderToNewSurface
 
-      Just (old_params, surface)
-        | old_params == params
-        -> return surface
+        Just (old_params, surface)
+          | old_params == params
+          -> return surface
 
-        | width  old_params == width  params &&
-          height old_params == height params
-        -> do
-             if old_params { hadjValue = hadjValue params } == params
-                -- only the hadjValue changed
-                && abs (hadjValue params - hadjValue old_params) <
-                   fromIntegral (width params) * scaleValue params
-                -- and the views overlap...
-               then
-                 scrollView surface old_params params hecs
-               else do
-                 renderWith surface $ do
-                   clearWhite; renderTraces params hecs rect
-                 return surface
+          | width  old_params == width  params &&
+            height old_params == height params
+          -> do
+              if old_params { hadjValue = hadjValue params } == params
+                  -- only the hadjValue changed
+                  && abs (hadjValue params - hadjValue old_params) <
+                    fromIntegral (width params) * scaleValue params
+                  -- and the views overlap...
+                then
+                  scrollView surface old_params params hecs
+                else do
+                  renderWith surface $ do
+                    clearWhite; renderTraces params hecs rect
+                  return surface
 
-        | otherwise
-        -> do surfaceFinish surface
-              renderToNewSurface
+          | otherwise
+          -> do surfaceFinish surface
+                renderToNewSurface
 
-  liftIO $ writeIORef timelinePrevView (Just (params, surface))
+    liftIO $ writeIORef timelinePrevView (Just (params, surface))
 
-  region exposeRegion
-  clip
-  setSourceSurface surface 0 (-vadj_value)
-          -- ^^ this is where we adjust for the vertical scrollbar
-  setOperator OperatorSource
-  paint
-  renderBookmarks bookmarks params
-  drawSelection params selection
+    region exposeRegion
+    clip
+    setSourceSurface surface 0 (-vadj_value)
+            -- ^^ this is where we adjust for the vertical scrollbar
+    setOperator OperatorSource
+    paint
+    renderBookmarks bookmarks params
+    drawSelection params selection
 
 -------------------------------------------------------------------------------
 
@@ -170,7 +170,7 @@ drawSelection vp@ViewParameters{height} (RangeSelection x x') = do
 -------------------------------------------------------------------------------
 
 -- We currently have two different way of converting from logical units
--- (ie timestamps in micro-seconds) to device units (ie pixels):
+-- (i.e. timestamps in micro-seconds) to device units (i.e. pixels):
 --   * the first is to set the cairo context to the appropriate scale
 --   * the second is to do the conversion ourself
 --
@@ -250,7 +250,7 @@ renderTraces params@ViewParameters{..} hecs (Rectangle rx _ry rw _rh) = do
                renderSparkConversion params slice start end (prof !! c)
              TracePoolHEC c ->
                let maxP = maxSparkPool hecs
-               in renderSparkPool params slice start end (prof !! c) maxP
+               in renderSparkPool slice start end (prof !! c) maxP
              TraceHistogram ->
                renderSparkHistogram params hecs
              TraceGroup _ -> error "renderTrace"
@@ -450,7 +450,7 @@ showTrace _ TraceActivity =
   "Activity"
 showTrace _ TraceGroup{} = error "Render.showTrace"
 
--- | Calcaulate the maximal Y value for a graph-like trace, or Nothing.
+-- | Calculate the maximal Y value for a graph-like trace, or Nothing.
 traceMaxSpark :: Double -> Double -> Double -> Trace -> Maybe Double
 traceMaxSpark maxS _ _ TraceCreationHEC{}   = Just $ maxS * 1000
 traceMaxSpark maxS _ _ TraceConversionHEC{} = Just $ maxS * 1000
